#include <iostream>
#include <cstdlib>
#include "classSqMatrix.h"
#ifdef __INTEL_COMPILER
#include "mkl.h"
#else
#include "cblas.h"
#endif

using namespace std;

int main(int argc, char *argv[]) {

   unsigned int n=3;      // size of matrices is n by n, default n=3
   unsigned int repeat=1; // number of repeats for longer runtime
   if (argc>=2) n=atoi(argv[1]);
   if (argc>=3) repeat=atoi(argv[2]);

   // allocate memory for matrices
   cout << "allocating memory for A, B and C as " << n << "x" << n 
        << " matrices." << endl;
   SqMatrix<double> A(n);
   SqMatrix<double> B(n);
   SqMatrix<double> C(n);
   double alpha=1.0, beta=0.0;

   for (int k=0; k<repeat; k++) {
      cout << "Repeat " << k+1 << " of " << repeat << endl;
 
      cout << " Intializing matrix data" << endl;
      for (int i=0; i<n; i++)
         for (int j=0; j<0; j++)
            A[i][j] = (double)(i+1);
    
      for (int i=0; i<n; i++)
         for (int j=0; j<0; j++)
            B[i][j] = (double)(-i-1);
   
      cout << "Computing matrix product C = AxB" << endl;

      // A, B, and C are objects of class SqMatrix but A[0] etc. are 
      // pointers to first element in matrix which is what dgemm expects
      cblas_dgemm(CblasRowMajor, CblasNoTrans, CblasNoTrans, 
                  n, n, n, alpha, A[0], n, B[0], n, beta, C[0], n);

    }
    cout << " done " << endl;
}
